@@ -96,7 +96,7 @@ sub resolve_disk_shortname {
   if ($disk =~ /^\d+$/) {
     # $disk-1 must be a valid index in the map of all disks in the system
     (scalar(@FAI::disks) >= $disk)
-      or die "this system does not have a physical disk $disk\n";
+      or die "This system does not have a physical disk $disk\n";
 
     # fetch the (short) device name
     $disk = $FAI::disks[ $disk - 1 ];
@@ -777,7 +777,7 @@ $FAI::Parser = Parse::RecDescent->new(
           $FAI::partition_pointer_dev_name = "/dev/md$vol_id";
         }
         mountpoint devices filesystem mount_options mdcreateopts
-        | /^btrfs (single|raid([0156]|10))\s+/
+        | /^btrfs\s+(single|raid([0156]|10))\s+/
         {
           ($FAI::device eq "BTRFS") or die "BTRFS entry invalid in this context.\n";
           defined $FAI::configs{BTRFS} or $FAI::configs{BTRFS}{volumes} = {};
